#
# spec file for package python-guessit
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-guessit
Version:        2.1.1
Release:        lp151.2.2
Summary:        GuessIt - a library for guessing information from video files
License:        LGPL-3.0
Group:          Development/Languages/Python
Url:            https://github.com/wackou/guessit
Source0:        https://pypi.io/packages/source/g/guessit/guessit-%{version}.tar.gz
BuildRequires:  %{python_module babelfish >= 0.5.5}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest-runner}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module rebulk >= 0.7.3}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-devel
BuildRequires:  python-pytest-runner
BuildRequires:  python-rebulk >= 0.7.3
BuildRequires:  python-rpm-macros
BuildRequires:  python-setuptools
Requires:       python-babelfish >= 0.5.5
Requires:       python-python-dateutil
Requires:       python-rebulk >= 0.7.3
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%python_subpackages

%description
GuessIt is a Python library that extracts as much information as
possible from a video file.
It has a filename matcher that allows to guess a lot of metadata from
a video using its filename only. This matcher works with both movies
and TV shows episodes.

%prep
%setup -q -n guessit-%{version}
# Remove shebang from non-executable files
for i in {'audio_codec','bonus','cds','container','country','crc','date','edition','episodes','episode_title','film','format','__init__','language','mimetype','other','part','release_group','screen_size','streaming_service','title','type','video_codec','website'}; do
sed -i -e "1d" "guessit/rules/properties/$i.py"
done
for i in {'common/comparators','common/date','common/formatters','common/__init__','common/numeral','common/validators','common/words','__init__','markers/groups','markers/__init__','markers/path','processors'}; do
sed -i -e "1d" "guessit/rules/$i.py"
done
for i in {'api','backports','__init__','jsonutils','__main__','options','reutils','test/__init__','test/rules/__init__','test/rules/processors_test','test/test_api','test/test_api_unicode_literals','test/test_benchmark','test/test_main','test/test_yml','__version__','yamlutils'}; do
sed -i -e "1d" "guessit/$i.py"
done

%build
%python_build

%install
%python_install
%python_expand %fdupes -s %%{buildroot}%{$python_sitelib}

%files %{python_files}
%defattr(-,root,root,-)
%python3_only %{_bindir}/guessit
%{python_sitelib}/guessit
%{python_sitelib}/guessit-%{version}-py%{python_version}.egg-info

%changelog
* Tue Apr 11 2017 jengelh@inai.de
- spellcasing fixes to the description; removal of extreme words.
* Fri Apr  7 2017 dmueller@suse.com
- fix dateutil dependency again
* Wed Mar  8 2017 aloisio@gmx.com
- Converted to single-spec
- Switched source URL to pypi.io
- Dropped self-generated manpage
- Dropped python-guessit-rpmlintrc (corrected relevant files)
* Thu Dec 15 2016 aloisio@gmx.com
- Update to version 2.1.1
  * Add `~` to episode/season separators.
  * Add `AHDTV`, `HDTC`, `SATRip` as new `format` possible
    values.
  * Add `streaming_service` property.
  * Add `DDP` pattern as `audio_codec`=`DolbyDigital`.
  * Add `LDTV` as possible tag for `other`=`LD`.
  * Add `StripSeparators` Post Processor to strip separators
    from all matches.
  * Fix invalid guess `1 x 2` with `--type episode`.
  * Fix `part` property.
  * Fix `cd_count` issue with `x264-CD`.
  * Fix `HDD` group detected as `DolbyDigital`.
  * Fix invalid comparator in `audio_codec` conflict solver.
  * Fix validation of `film` property.
  * Fix `date` followed by `screen_size` invalid guess.
  * Fix `episode` not detected when smaller filepart repeats the
    `season` and uses `SSEE` pattern.
  * Enhance `season`/`episode` conflict solver to keep most
    specific value.
  * Enhance `video_profile` detection.
  * Enhance `episode`/`season` range and sequence guessing.
  * Enhance performance with rebulk upgrade to `0.8.2`.
  * Enhance `season`/`episode`.
  * Enhance `other`=`Complete` guessing.
  * Enhance `release_group` guessing.
  * Enhance command line options parsing related to unicode.
  * Ensure roman numbers are surrounded with separators to be
    guessed as numbers.
* Fri Sep  9 2016 aloisio@gmx.com
- Update to version 2.1.0
  * Drop support for `regex` native module.
  * Remove dependency constraint on `python-dateutil`.
  * Enhance langage/country guessing in edge cases.
  * Enhance rule to guess `release_group` in more file
    templates.
  * Fix edge cases for subtitle language detection.
  * Fix invalid conflict solving in `season`/`episode`
    occuring between `SssEee` and `ssXee` pattern.
  * Fix issue when running guessit in non-interactive shell
    with python 2
  * Guess Dolby keyword as DolbyDigital in `audio_codec`.
  * Avoid `title` to be guessed as `website` (Dark.Net)
  * Avoid `season`/`episode` to be guessed when pattern is
    included inside words.
  * Enhance `screen_size` to detect `720pHD` and `1080pHD`
  * Add support for `format` and `video_codec` when no
    separators between themselves. (HDTVx264, PDTVx264, ...)
  * Add rebulk version in `--version` option.
  * Upgrade rebulk to `0.7.3`.
* Mon Apr 25 2016 aloisio@gmx.com
- Update to version 2.0.5
  * Fix inconsistent properties returned by guessit -p.
  * Add support for titles containing dots.
  * Lock python-dateutil dependency to <2.5.2.
  * Add an Exception Report when an unexpected exception occurs.
  * Fix possible issue with unicode characters encoding/decoding.
  * Add support for any type of string with python 2 and python 3
    (binary, str, unicode).
  * Remove regex native module from required dependencies.
    It will now be used only if present.
  * Guessit is now available as a docker container on Docker Hub
    (https://hub.docker.com/r/toilal/guessit).
  * `country` 2-letter code is not added to `title` value anymore.
  * All `container` values are now capitalized.
  * `alternativeTitle` has been renamed to `alternative_title`
    and added to the docs.
  * `mimetype` property is now in the docs.
  * Add more excluded words for `language` property.
  * Add more possible values for `other` property.
  * Fix an issue occuring with `title` values starting with `Scr`.
  * `film` property is now guessed only if less than `100` to
    avoid possible conflicts with `crc32`.
  * Add docs.
  * Add exotic `screen_size` patterns support like `720hd`
    and `720p50`.
  * Rename `audio_codec` value `true-HD` to `trueHD`.
  * Add ``__version__`` to main module.
  * Single digit episodes are now guessed for ``--type episode``
    instead of ``--episode-prefer-number``.
  * Fix separators that could cause some titles to be splited
    with & and ;.
  * Avoid possible ``NoneType`` error.
  * Fallback to default title guessing when ``expected-title``
    is not found.
  * Add ``expected-group`` option.
  * Add validation rule for single digit ``episode`` to avoid
    false positives.
  * Add ``verbose`` option.
  * Fix ``expected-title`` option.
  * Better unicode support in ``expected-group``/``expected-title``
    option.
  * Add support for ``part`` with no space before number.
  * Avoid ``uuid`` and ``crc32`` collision with
    ``season``/``episode`` properties.
  * Add better space support for ``season``/``episode`` properties.
  * Ensure ``date`` property is found when conflicting with
    ``season``/``episode`` properties.
  * Fix ``IndexError`` when input has a closing group character
    with no opening one before.
  * Add ``--type`` option.
  * Add rebulk implicit option support.
  * Add python 2.6 support.
  * Enhance title guessing.
  * Upgrade rebulk to ``0.6.1``.
  * Rename ``properCount`` to ``proper_count``
  * Avoid crash when using ``-p``/``-V`` option with ``--yaml``
    and ``yaml`` module is not available.
  * Add ``-p``/``-V`` options to display properties and values
    that can be guessed.
  * Allow rebulk customization in API module.
  * Raise TypeError instead of AssertionError when non text
    is given to guessit API.
  * Rewrite from scratch using Rebulk.
- Added man page for guessit
* Sat Jul 18 2015 aloisio@gmx.com
- Update to version 0.10.3
  * Fix issues related to unicode encoding/decoding
  * Fix possible crashes in guess_video_rexps
  * Fix invalid guess result when crc32 contains 6 digits than
    can be parsed as a date
  version 0.10.2:
  * Use common words to resolve conflicts on strings
  * Bump babelfish version
  * Fix setuptools deprecation warning
  * Package argparse dependency only if python<2.7
* Wed Feb 11 2015 aloisio@gmx.com
- Initial version 1.0.1
